#delim ;
version 11.0;
*
 Create dataset spparam1.dta
 with 1 obs per spline degree per reference spline parameter
 and data on estimates and confidence limits
 and dataset spxval1.dta
 with 1 obs per spline degree per x-value
 and data on spline basis values and fitted spline values.
 SSC packages used:
 scheme_rbn1mono, bspline, descsave, keyby, parmest
*;

clear all;
set memory 1m;
set scheme rbn2mono;

*
 Define value labels for spline degree
*;
lab def power 0 "Step spline" 1 "Linear spline" 2 "Quadratic spline" 3 "Cubic spline";
tempfile lf0;
lab save power using `"`lf0'"';

*
 Input data
*;
sysuse auto, clear;
desc;
summ weight, de;
local minwei=r(min);
local maxwei=r(max);
local nwei=`maxwei'-`minwei'+1;
tempfile df0;
descsave weight, do(`"`df0'"', replace);

*
 Create datasets to be concatenated
 for each spline power
*;
global pflist "";
global xflist "";
numlist "1760(616)4840";
local refpoints "`r(numlist)'";
foreach SP of num 0(1)3 {;
  disp _n as text "Spline power: " as result "`SP'";
  local incopt "";
  if `SP'==0 {;local incopt "inc(5456)";};
  flexcurv, xvar(weight) refpts(`refpoints') `incopt' power(`SP') gene(sp_);
  desc sp_*;
  regress mpg sp_*, noconst nohead;
  tempfile pfcur;
  parmest, label idnum(`SP') saving(`"`pfcur'"', replace) flis(pflist);
  preserve;
  clear;
  set obs `nwei';
  gene int weight=`minwei'+_n-1;
  run `"`df0'"';
  gene byte power=`SP';
  lab var power "Degree of spline";
  keyby power weight;
  flexcurv, xvar(weight) refpts(`refpoints') `incopt' power(`SP') gene(sp_);
  predict mpghat;
  desc;
  tempfile xfcur;
  save `"`xfcur'"', replace;
  global xflist `"$xflist `"`xfcur'"'"';
  restore;
  drop sp_*;  
};

*
 Create dataset spparam1.dta
*;
clear;
append using $pflist;
rename idnum power;
lab var power "Degree of spline";
gene weight=real(subinstr(subinstr(label,"Spline at ","",1),",","",.));
run `"`df0'"';
run `"`lf0'"';
lab val power power;
drop label;
keyby power weight;
char _dta[refpoints] "`refpoints'";
desc;
char list;
list, sepby(power);
save spparam1, replace;

*
 Create dataset spxval1.dta
*;
clear;
append using $xflist;
run `"`lf0'"';
lab val power power;
keyby power weight;
char _dta[refpoints] "`refpoints'";
desc;
char list;
tab power, m;
save spxval1, replace;

* Plots *;
local mymsize 0.1875;
unab splist: sp_*;
local nsp: word count `splist';
mata: st_local("mymsizes",strtoreal(st_local("nsp"))*(" "+st_local("mymsize")));
mata: st_local("mysims",strtoreal(st_local("nsp"))*" circle");
scatter mpghat weight, msize(0.25) || , by(power) xlab(`refpoints');
more;
scatter sp_* weight,
  msym(`mysims') msize(`mymsizes') || ,
  by(power, legend(off)) xlab(`refpoints');
more;

exit;
