#delim ;
version 11.0;
*
 Input Stata dataset spxval1.dta.
 Create figures figseq3.eps to figseq6.eps
 for spline bases for spline models
 of mpg with respect to weight.
 SSC packages used:
 scheme_rbn1mono, varlabdef, keyby, lablist, regaxis
*;

clear all;
set memory 2m;
set scheme rbn2mono;

*
 Input dataset spxval1
 and expand it to have 1 obs per power per reference spline per X-value
 and data on predicted spline value
*;
use spxval1, clear;
desc;
local refpoints "`_dta[refpoints]'";
varlabdef refseq, vlist(sp_*);
reshape long sp_, i(power weight) j(refseq);
rename sp_ refspline;
lab var refspline "Reference spline value";
format refspline %8.0g;
lab var refseq "Reference spline";
lab val refseq refseq;
keyby power refseq weight;
desc;
lablist, var;
tab refseq power, m;

*
 Create plots
*;
local figseq=2;
levelsof power, lo(powers);
foreach PO of num `powers' {;
  local POlab: lab (power) `PO';
  local Ytit=subinstr("`POlab'"," spline", " reference spline value",1);
  local figseq=`figseq'+1;
  preserve;
  keep if power==`PO';
  regaxis refspline, cy(0.25) ltick(ylabs);
  scatter refspline weight, msym(circle) msize(0.25) ||,
    by(refseq, row(2) legend(off)) subt(, size(3))
    ylab(`ylabs', labsize(3)) yline(0 1) ytitle("`Ytit'", size(3))
    xlab(`refpoints', labsize(3)) xtit(, size(3))
    xsize(6.5) ysize(3.75);
  graph export figseq`figseq'.eps, replace;
  more;
  restore;
};

exit;
